Refactor header to use user rights. (#57)
[timetracker.git] / users.php
index 15850d2..35fd416 100644 (file)
--- a/users.php
+++ b/users.php
@@ -30,9 +30,10 @@ require_once('initialize.php');
 import('form.Form');
 import('ttTeamHelper');
 import('ttTimeHelper');
+import('ttRoleHelper');
 
 // Access check.
-if (!ttAccessCheck(right_data_entry)) {
+if (!(ttAccessAllowed('view_users') || ttAccessAllowed('manage_users'))) {
   header('Location: access_denied.php');
   exit();
 }
@@ -44,8 +45,8 @@ if($user->canManageTeam()) {
   $inactive_users = ttTeamHelper::getInactiveUsers($user->team_id, true);
 }
 
-// Check if the user wants to show uncompleted time entries.
-if (ENTRIES_USERS_PAGE == $user->uncompleted_entries) {
+// Check if the team is set to show indicators for uncompleted time entries.
+if ($user->uncompleted_indicators) {
   // Check each active user if they have an uncompleted time entry.
   foreach ($active_users as $key => $user) {
     $active_users[$key]['has_uncompleted_entry'] = (bool) ttTimeHelper::getUncompleted($user['id']);
@@ -55,6 +56,6 @@ if (ENTRIES_USERS_PAGE == $user->uncompleted_entries) {
 $smarty->assign('active_users', $active_users);
 $smarty->assign('inactive_users', $inactive_users);
 $smarty->assign('can_delete_manager', $can_delete_manager);
-$smarty->assign('title', $i18n->getKey('title.users'));
+$smarty->assign('title', $i18n->get('title.users'));
 $smarty->assign('content_page_name', 'users.tpl');
 $smarty->display('index.tpl');